summaryrefslogtreecommitdiff
path: root/boost/asio/detail/strand_service.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'boost/asio/detail/strand_service.hpp')
-rw-r--r--boost/asio/detail/strand_service.hpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/boost/asio/detail/strand_service.hpp b/boost/asio/detail/strand_service.hpp
index 8a94e58e36..e9d05b3ae7 100644
--- a/boost/asio/detail/strand_service.hpp
+++ b/boost/asio/detail/strand_service.hpp
@@ -16,7 +16,7 @@
#endif // defined(_MSC_VER) && (_MSC_VER >= 1200)
#include <boost/asio/detail/config.hpp>
-#include <boost/asio/io_service.hpp>
+#include <boost/asio/io_context.hpp>
#include <boost/asio/detail/mutex.hpp>
#include <boost/asio/detail/op_queue.hpp>
#include <boost/asio/detail/operation.hpp>
@@ -75,20 +75,20 @@ public:
typedef strand_impl* implementation_type;
- // Construct a new strand service for the specified io_service.
- BOOST_ASIO_DECL explicit strand_service(boost::asio::io_service& io_service);
+ // Construct a new strand service for the specified io_context.
+ BOOST_ASIO_DECL explicit strand_service(boost::asio::io_context& io_context);
// Destroy all user-defined handler objects owned by the service.
- BOOST_ASIO_DECL void shutdown_service();
+ BOOST_ASIO_DECL void shutdown();
// Construct a new strand implementation.
BOOST_ASIO_DECL void construct(implementation_type& impl);
// Request the io_service to invoke the given handler.
template <typename Handler>
void dispatch(implementation_type& impl, Handler& handler);
// Request the io_service to invoke the given handler and return immediately.
template <typename Handler>
void post(implementation_type& impl, Handler& handler);
@@ -105,12 +105,12 @@ private:
BOOST_ASIO_DECL void do_post(implementation_type& impl,
operation* op, bool is_continuation);
- BOOST_ASIO_DECL static void do_complete(io_service_impl* owner,
+ BOOST_ASIO_DECL static void do_complete(void* owner,
operation* base, const boost::system::error_code& ec,
std::size_t bytes_transferred);
- // The io_service implementation used to post completions.
- io_service_impl& io_service_;
+ // The io_context implementation used to post completions.
+ io_context_impl& io_context_;
// Mutex to protect access to the array of implementations.
boost::asio::detail::mutex mutex_;
@@ -75,20 +75,20 @@ public:
// Construct a new strand implementation.
BOOST_ASIO_DECL void construct(implementation_type& impl);
- // Request the io_service to invoke the given handler.
+ // Request the io_context to invoke the given handler.
template <typename Handler>
void dispatch(implementation_type& impl, Handler& handler);
@@ -75,20 +75,20 @@ public:
template <typename Handler>
void dispatch(implementation_type& impl, Handler& handler);
- // Request the io_service to invoke the given handler and return immediately.
+ // Request the io_context to invoke the given handler and return immediately.
template <typename Handler>
void post(implementation_type& impl, Handler& handler);